// This file is auto-generated by @hey-api/openapi-ts

/**
 * A key-value pair for a known and supported API.
 */
export type ApiKeyReadable = {
    id: string;
};

/**
 * A key-value pair for a known and supported API.
 */
export type ApiKeyWritable = {
    id: string;
    key: string;
};

/**
 * The ``access`` block contains information related to access control for
 * this data object.
 */
export type Access = {
    asset: Asset;
    classification?: Classification | null;
};

/**
 * A key-value pair for a known and supported access scope.
 */
export type AccessTokenReadable = {
    id: string;
};

/**
 * A key-value pair for a known and supported access scope.
 */
export type AccessTokenWritable = {
    id: string;
    key: string;
};

/**
 * The ``access.asset`` block contains information about the owner asset of
 * these data.
 */
export type Asset = {
    name: string;
};

/**
 * The security classification for a given data object.
 */
export type Classification = 'asset' | 'internal' | 'restricted';

/**
 * The ``masterdata.smda.coordinate_system`` block contains the coordinate
 * system known to SMDA.
 */
export type CoordinateSystem = {
    identifier: string;
    uuid: string;
};

/**
 * A single country in the ``smda.masterdata.country`` list of countries
 * known to SMDA.
 */
export type CountryItem = {
    identifier: string;
    uuid: string;
};

/**
 * A single discovery in the ``masterdata.smda.discovery`` list of discoveries
 * known to SMDA.
 */
export type DiscoveryItem = {
    short_identifier: string;
    uuid: string;
};

/**
 * Path where a .fmu directory may exist.
 */
export type FmuDirPath = {
    /**
     * Absolute path to the directory which maybe contains a .fmu directory.
     */
    path: string;
};

/**
 * Information returned when 'opening' an FMU Directory.
 */
export type FmuProject = {
    /**
     * Absolute path to the directory which maybe contains a .fmu directory.
     */
    path: string;
    /**
     * The directory name, not the path, that contains the .fmu directory.
     */
    project_dir_name: string;
    /**
     * The configuration of an FMU project's .fmu directory.
     */
    config: ProjectConfig;
    /**
     * Whether the project is in read-only mode due to lock conflicts.
     */
    is_read_only?: boolean;
};

/**
 * A single field in the ``masterdata.smda.field`` list of fields
 * known to SMDA.
 */
export type FieldItem = {
    identifier: string;
    uuid: string;
};

/**
 * A relative path to a global config file, relative to the project root.
 */
export type GlobalConfigPath = {
    /**
     * Relative path in the project to a global config file.
     */
    relative_path: string;
};

export type HttpValidationError = {
    detail?: Array<ValidationError>;
};

/**
 * Represents a .fmu directory lock file.
 */
export type LockInfo = {
    pid: number;
    hostname: string;
    user: string;
    acquired_at: number;
    expires_at: number;
    version?: string;
};

/**
 * Information about the project lock status.
 */
export type LockStatus = {
    /**
     * Whether the current session holds the write lock.
     */
    is_lock_acquired: boolean;
    /**
     * Whether a lock file exists.
     */
    lock_file_exists: boolean;
    /**
     * Contents of the lock file, if available and readable.
     */
    lock_info?: LockInfo | null;
    /**
     * Error message if checking lock status failed.
     */
    lock_status_error?: string | null;
    /**
     * Error message if reading the lock file failed.
     */
    lock_file_read_error?: string | null;
    /**
     * Error message from the last attempt to acquire the lock.
     */
    last_lock_acquire_error?: string | null;
    /**
     * Error message from the last attempt to release the lock.
     */
    last_lock_release_error?: string | null;
    /**
     * Error message from the last attempt to refresh the lock.
     */
    last_lock_refresh_error?: string | null;
};

/**
 * The ``masterdata`` block contains information related to masterdata.
 * Currently, SMDA holds the masterdata.
 */
export type Masterdata = {
    smda: Smda;
};

/**
 * A generic message to return to the GUI.
 */
export type Message = {
    message: string;
};

/**
 * The ``fmu.model`` block contains information about the model used.
 *
 * .. note::
 * Synonyms for "model" in this context are "template", "setup", etc. The term
 * "model" is ultra-generic but was chosen before e.g. "template" as the latter
 * deviates from daily communications and is, if possible, even more generic
 * than "model".
 */
export type Model = {
    description?: Array<string> | null;
    name: string;
    revision: string;
};

/**
 * Returns "ok" if the route is functioning correctly.
 */
export type Ok = {
    status?: 'ok';
};

/**
 * The configuration file in a .fmu directory.
 *
 * Stored as config.json.
 */
export type ProjectConfig = {
    version: string;
    created_at: string;
    created_by: string;
    masterdata?: Masterdata | null;
    model?: Model | null;
    access?: Access | null;
};

/**
 * The ``masterdata.smda`` block contains SMDA-related attributes.
 */
export type Smda = {
    coordinate_system: CoordinateSystem;
    country: Array<CountryItem>;
    discovery: Array<DiscoveryItem>;
    field: Array<FieldItem>;
    stratigraphic_column: StratigraphicColumn;
};

/**
 * An identifier for a field to be searched for.
 */
export type SmdaField = {
    /**
     * A field identifier (name).
     */
    identifier: string;
};

/**
 * The search result of a field identifier result.
 */
export type SmdaFieldSearchResult = {
    /**
     * The number of hits from the field search.
     */
    hits: number;
    /**
     * The number of pages of hits.
     */
    pages: number;
    /**
     * A list of field identifier results from the search.
     */
    results: Array<SmdaFieldUuid>;
};

/**
 * Name-UUID identifier for a field as known by SMDA.
 */
export type SmdaFieldUuid = {
    /**
     * A field identifier (name).
     */
    identifier: string;
    /**
     * The SMDA UUID identifier corresponding to the field identifier.
     */
    uuid: string;
};

/**
 * Contains SMDA-related attributes.
 */
export type SmdaMasterdataResult = {
    /**
     * A list referring to fields known to SMDA. First item is primary.
     */
    field: Array<FieldItem>;
    /**
     * A list referring to countries known to SMDA. First item is primary.
     */
    country: Array<CountryItem>;
    /**
     * A list referring to discoveries known to SMDA. First item is primary.
     */
    discovery: Array<DiscoveryItem>;
    /**
     * Reference to stratigraphic column known to SMDA.
     */
    stratigraphic_columns: Array<StratigraphicColumn>;
    /**
     * The primary field's coordinate system.
     *
     * This coordinate system may not be the coordinate system users use in their model.
     */
    field_coordinate_system: CoordinateSystem;
    /**
     * A list of all coordinate systems known to SMDA.
     *
     * These are provided when the user needs to select a different coordinate system that
     * applies to the model they are working on.
     */
    coordinate_systems: Array<CoordinateSystem>;
};

/**
 * The ``masterdata.smda.stratigraphic_column`` block contains the
 * stratigraphic column known to SMDA.
 */
export type StratigraphicColumn = {
    identifier: string;
    uuid: string;
};

/**
 * Known API keys stored in a user config.
 */
export type UserApiKeys = {
    smda_subscription?: string | null;
};

/**
 * The configuration file in a $HOME/.fmu directory.
 *
 * Stored as config.json.
 */
export type UserConfig = {
    version: string;
    created_at: string;
    user_api_keys: UserApiKeys;
    recent_project_directories: Array<string>;
};

export type ValidationError = {
    loc: Array<string | number>;
    msg: string;
    type: string;
};

export type ProjectDeleteProjectSessionData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/v1/project/';
};

export type ProjectDeleteProjectSessionErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type ProjectDeleteProjectSessionError = ProjectDeleteProjectSessionErrors[keyof ProjectDeleteProjectSessionErrors];

export type ProjectDeleteProjectSessionResponses = {
    /**
     * Successful Response
     */
    200: Message;
};

export type ProjectDeleteProjectSessionResponse = ProjectDeleteProjectSessionResponses[keyof ProjectDeleteProjectSessionResponses];

export type ProjectGetProjectData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/v1/project/';
};

export type ProjectGetProjectErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * The OS returned a permissions error while locating or creating .fmu
     */
    403: unknown;
    /**
     *
     * The .fmu directory was unable to be found at or above a given path, or
     * the requested path to create a project .fmu directory at does not exist.
     *
     */
    404: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type ProjectGetProjectError = ProjectGetProjectErrors[keyof ProjectGetProjectErrors];

export type ProjectGetProjectResponses = {
    /**
     * Successful Response
     */
    200: FmuProject;
};

export type ProjectGetProjectResponse = ProjectGetProjectResponses[keyof ProjectGetProjectResponses];

export type ProjectPostProjectData = {
    body: FmuDirPath;
    path?: never;
    query?: never;
    url: '/api/v1/project/';
};

export type ProjectPostProjectErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * The OS returned a permissions error while locating or creating .fmu
     */
    403: unknown;
    /**
     *
     * The .fmu directory was unable to be found at or above a given path, or
     * the requested path to create a project .fmu directory at does not exist.
     *
     */
    404: unknown;
    /**
     *
     * A project .fmu directory already exist at a given location, or may
     * possibly not be a directory, i.e. it may be a .fmu file.
     *
     */
    409: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type ProjectPostProjectError = ProjectPostProjectErrors[keyof ProjectPostProjectErrors];

export type ProjectPostProjectResponses = {
    /**
     * Successful Response
     */
    200: FmuProject;
};

export type ProjectPostProjectResponse = ProjectPostProjectResponses[keyof ProjectPostProjectResponses];

export type ProjectGetGlobalConfigStatusData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/v1/project/global_config_status';
};

export type ProjectGetGlobalConfigStatusErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     *
     * The global config file was not found at a given location.
     *
     */
    404: unknown;
    /**
     *
     * The project .fmu config already contains masterdata.
     *
     */
    409: unknown;
    /**
     *
     * The global config file did not validate against the
     * GlobalConfiguration Pydantic model.
     *
     */
    422: unknown;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type ProjectGetGlobalConfigStatusResponses = {
    /**
     * Successful Response
     */
    200: Ok;
};

export type ProjectGetGlobalConfigStatusResponse = ProjectGetGlobalConfigStatusResponses[keyof ProjectGetGlobalConfigStatusResponses];

export type ProjectInitProjectData = {
    body: FmuDirPath;
    path?: never;
    query?: never;
    url: '/api/v1/project/init';
};

export type ProjectInitProjectErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * The OS returned a permissions error while locating or creating .fmu
     */
    403: unknown;
    /**
     *
     * The .fmu directory was unable to be found at or above a given path, or
     * the requested path to create a project .fmu directory at does not exist.
     *
     */
    404: unknown;
    /**
     *
     * A project .fmu directory already exist at a given location, or may
     * possibly not be a directory, i.e. it may be a .fmu file.
     *
     */
    409: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type ProjectInitProjectError = ProjectInitProjectErrors[keyof ProjectInitProjectErrors];

export type ProjectInitProjectResponses = {
    /**
     * Successful Response
     */
    200: FmuProject;
};

export type ProjectInitProjectResponse = ProjectInitProjectResponses[keyof ProjectInitProjectResponses];

export type ProjectPostGlobalConfigData = {
    body?: GlobalConfigPath | null;
    path?: never;
    query?: never;
    url: '/api/v1/project/global_config';
};

export type ProjectPostGlobalConfigErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     *
     * The global config file was not found at a given location.
     *
     */
    404: unknown;
    /**
     *
     * The project .fmu config already contains masterdata.
     *
     */
    409: unknown;
    /**
     *
     * The global config file did not validate against the
     * GlobalConfiguration Pydantic model.
     *
     */
    422: unknown;
    /**
     *
     * The project is locked by another process and cannot be modified.
     * The project can still be read but write operations are blocked.
     *
     */
    423: unknown;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type ProjectPostGlobalConfigResponses = {
    /**
     * Successful Response
     */
    200: Message;
};

export type ProjectPostGlobalConfigResponse = ProjectPostGlobalConfigResponses[keyof ProjectPostGlobalConfigResponses];

export type ProjectPostLockAcquireData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/v1/project/lock_acquire';
};

export type ProjectPostLockAcquireErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type ProjectPostLockAcquireError = ProjectPostLockAcquireErrors[keyof ProjectPostLockAcquireErrors];

export type ProjectPostLockAcquireResponses = {
    /**
     * Successful Response
     */
    200: Message;
};

export type ProjectPostLockAcquireResponse = ProjectPostLockAcquireResponses[keyof ProjectPostLockAcquireResponses];

export type ProjectGetLockStatusData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/v1/project/lock_status';
};

export type ProjectGetLockStatusErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * The OS returned a permissions error while locating or creating .fmu
     */
    403: unknown;
    /**
     *
     * The .fmu directory was unable to be found at or above a given path, or
     * the requested path to create a project .fmu directory at does not exist.
     *
     */
    404: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type ProjectGetLockStatusError = ProjectGetLockStatusErrors[keyof ProjectGetLockStatusErrors];

export type ProjectGetLockStatusResponses = {
    /**
     * Successful Response
     */
    200: LockStatus;
};

export type ProjectGetLockStatusResponse = ProjectGetLockStatusResponses[keyof ProjectGetLockStatusResponses];

export type ProjectPatchMasterdataData = {
    body: Smda;
    path?: never;
    query?: never;
    url: '/api/v1/project/masterdata';
};

export type ProjectPatchMasterdataErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * The OS returned a permissions error while locating or creating .fmu
     */
    403: unknown;
    /**
     *
     * The .fmu directory was unable to be found at or above a given path, or
     * the requested path to create a project .fmu directory at does not exist.
     *
     */
    404: unknown;
    /**
     *
     * A project .fmu directory already exist at a given location, or may
     * possibly not be a directory, i.e. it may be a .fmu file.
     *
     */
    409: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     *
     * The project is locked by another process and cannot be modified.
     * The project can still be read but write operations are blocked.
     *
     */
    423: unknown;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type ProjectPatchMasterdataError = ProjectPatchMasterdataErrors[keyof ProjectPatchMasterdataErrors];

export type ProjectPatchMasterdataResponses = {
    /**
     * Successful Response
     */
    200: Message;
};

export type ProjectPatchMasterdataResponse = ProjectPatchMasterdataResponses[keyof ProjectPatchMasterdataResponses];

export type ProjectPatchModelData = {
    body: Model;
    path?: never;
    query?: never;
    url: '/api/v1/project/model';
};

export type ProjectPatchModelErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * The OS returned a permissions error while locating or creating .fmu
     */
    403: unknown;
    /**
     *
     * The .fmu directory was unable to be found at or above a given path, or
     * the requested path to create a project .fmu directory at does not exist.
     *
     */
    404: unknown;
    /**
     *
     * A project .fmu directory already exist at a given location, or may
     * possibly not be a directory, i.e. it may be a .fmu file.
     *
     */
    409: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     *
     * The project is locked by another process and cannot be modified.
     * The project can still be read but write operations are blocked.
     *
     */
    423: unknown;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type ProjectPatchModelError = ProjectPatchModelErrors[keyof ProjectPatchModelErrors];

export type ProjectPatchModelResponses = {
    /**
     * Successful Response
     */
    200: Message;
};

export type ProjectPatchModelResponse = ProjectPatchModelResponses[keyof ProjectPatchModelResponses];

export type ProjectPatchAccessData = {
    body: Access;
    path?: never;
    query?: never;
    url: '/api/v1/project/access';
};

export type ProjectPatchAccessErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * The OS returned a permissions error while locating or creating .fmu
     */
    403: unknown;
    /**
     *
     * The .fmu directory was unable to be found at or above a given path, or
     * the requested path to create a project .fmu directory at does not exist.
     *
     */
    404: unknown;
    /**
     *
     * A project .fmu directory already exist at a given location, or may
     * possibly not be a directory, i.e. it may be a .fmu file.
     *
     */
    409: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     *
     * The project is locked by another process and cannot be modified.
     * The project can still be read but write operations are blocked.
     *
     */
    423: unknown;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type ProjectPatchAccessError = ProjectPatchAccessErrors[keyof ProjectPatchAccessErrors];

export type ProjectPatchAccessResponses = {
    /**
     * Successful Response
     */
    200: Message;
};

export type ProjectPatchAccessResponse = ProjectPatchAccessResponses[keyof ProjectPatchAccessResponses];

export type UserGetUserData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/v1/user/';
};

export type UserGetUserErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * The OS returned a permissions error while locating or creating .fmu
     */
    403: unknown;
    /**
     *
     * The .fmu directory was unable to be found at or above a given path, or
     * the requested path to create a project .fmu directory at does not exist.
     *
     */
    404: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type UserGetUserError = UserGetUserErrors[keyof UserGetUserErrors];

export type UserGetUserResponses = {
    /**
     * Successful Response
     */
    200: UserConfig;
};

export type UserGetUserResponse = UserGetUserResponses[keyof UserGetUserResponses];

export type UserPatchApiKeyData = {
    body: ApiKeyWritable;
    path?: never;
    query?: never;
    url: '/api/v1/user/api_key';
};

export type UserPatchApiKeyErrors = {
    /**
     *
     * Occurs when trying to save a key to an unknown API. An API is unknown
     * if it is not a predefined field in the fmu-settings UserAPIKeys model.
     *
     */
    400: unknown;
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * The OS returned a permissions error while locating or creating .fmu
     */
    403: unknown;
    /**
     *
     * The .fmu directory was unable to be found at or above a given path, or
     * the requested path to create a project .fmu directory at does not exist.
     *
     */
    404: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type UserPatchApiKeyError = UserPatchApiKeyErrors[keyof UserPatchApiKeyErrors];

export type UserPatchApiKeyResponses = {
    /**
     * Successful Response
     */
    200: Message;
};

export type UserPatchApiKeyResponse = UserPatchApiKeyResponses[keyof UserPatchApiKeyResponses];

export type SessionCreateSessionData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/v1/session/';
};

export type SessionCreateSessionErrors = {
    /**
     *
     * Occurs when no token or an invalid token is or is not provided
     * with the x-fmu-settings-api header.
     *
     */
    401: unknown;
    /**
     *
     * Will occur if the operating system claims the user does not have
     * permission to create $HOME/.fmu. If returned something very wrong
     * is happening.
     *
     */
    403: unknown;
    /**
     *
     * Occurs in two cases:
     *
     * - When attempting to create a session when one already exists
     * - When trying to create a user .fmu directory, but it already
     * exists. Typically means that .fmu exists as a file.
     *
     */
    409: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type SessionCreateSessionError = SessionCreateSessionErrors[keyof SessionCreateSessionErrors];

export type SessionCreateSessionResponses = {
    /**
     * Successful Response
     */
    200: Message;
};

export type SessionCreateSessionResponse = SessionCreateSessionResponses[keyof SessionCreateSessionResponses];

export type SessionPatchAccessTokenData = {
    body: AccessTokenWritable;
    path?: never;
    query?: never;
    url: '/api/v1/session/access_token';
};

export type SessionPatchAccessTokenErrors = {
    /**
     *
     * Occurs when trying to save a key to an unknown access scope. An
     * access scope/token is unknown if it is not a predefined field in the
     * the session manager's 'AccessTokens' model.
     *
     */
    400: unknown;
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type SessionPatchAccessTokenError = SessionPatchAccessTokenErrors[keyof SessionPatchAccessTokenErrors];

export type SessionPatchAccessTokenResponses = {
    /**
     * Successful Response
     */
    200: Message;
};

export type SessionPatchAccessTokenResponse = SessionPatchAccessTokenResponses[keyof SessionPatchAccessTokenResponses];

export type SmdaGetHealthData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/v1/smda/health';
};

export type SmdaGetHealthErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type SmdaGetHealthError = SmdaGetHealthErrors[keyof SmdaGetHealthErrors];

export type SmdaGetHealthResponses = {
    /**
     * Successful Response
     */
    200: Ok;
};

export type SmdaGetHealthResponse = SmdaGetHealthResponses[keyof SmdaGetHealthResponses];

export type SmdaPostFieldData = {
    body: SmdaField;
    path?: never;
    query?: never;
    url: '/api/v1/smda/field';
};

export type SmdaPostFieldErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type SmdaPostFieldError = SmdaPostFieldErrors[keyof SmdaPostFieldErrors];

export type SmdaPostFieldResponses = {
    /**
     * Successful Response
     */
    200: SmdaFieldSearchResult;
};

export type SmdaPostFieldResponse = SmdaPostFieldResponses[keyof SmdaPostFieldResponses];

export type SmdaPostMasterdataData = {
    body: Array<SmdaField>;
    path?: never;
    query?: never;
    url: '/api/v1/smda/masterdata';
};

export type SmdaPostMasterdataErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
    /**
     * Occurs when an API call to SMDA times out.
     */
    503: unknown;
};

export type SmdaPostMasterdataError = SmdaPostMasterdataErrors[keyof SmdaPostMasterdataErrors];

export type SmdaPostMasterdataResponses = {
    /**
     * Successful Response
     */
    200: SmdaMasterdataResult;
};

export type SmdaPostMasterdataResponse = SmdaPostMasterdataResponses[keyof SmdaPostMasterdataResponses];

export type HealthV1HealthCheckData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/v1/health';
};

export type HealthV1HealthCheckErrors = {
    /**
     * No active or valid session was found
     */
    401: unknown;
    /**
     * Validation Error
     */
    422: HttpValidationError;
    /**
     * Something unexpected has happened
     */
    500: unknown;
};

export type HealthV1HealthCheckError = HealthV1HealthCheckErrors[keyof HealthV1HealthCheckErrors];

export type HealthV1HealthCheckResponses = {
    /**
     * Successful Response
     */
    200: Ok;
};

export type HealthV1HealthCheckResponse = HealthV1HealthCheckResponses[keyof HealthV1HealthCheckResponses];

export type HealthHealthCheckData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/health';
};

export type HealthHealthCheckResponses = {
    /**
     * Successful Response
     */
    200: Ok;
};

export type HealthHealthCheckResponse = HealthHealthCheckResponses[keyof HealthHealthCheckResponses];

export type ClientOptions = {
    baseURL: 'http://localhost:8001' | (string & {});
};