/* eslint-disable */

// @ts-nocheck

// noinspection JSUnusedGlobalSymbols

// This file was automatically generated by TanStack Router.
// You should NOT make any changes in this file as it will be overwritten.
// Additionally, you should also exclude this file from your linter and/or formatter to prevent it from being checked or modified.

// Import Routes

import { Route as rootRoute } from "./routes/__root";
import { Route as IndexImport } from "./routes/index";
import { Route as ProjectIndexImport } from "./routes/project/index";
import { Route as UserKeysImport } from "./routes/user/keys";
import { Route as ProjectMasterdataImport } from "./routes/project/masterdata";

// Create/Update Routes

const IndexRoute = IndexImport.update({
  id: "/",
  path: "/",
  getParentRoute: () => rootRoute,
} as any);

const ProjectIndexRoute = ProjectIndexImport.update({
  id: "/project/",
  path: "/project/",
  getParentRoute: () => rootRoute,
} as any);

const UserKeysRoute = UserKeysImport.update({
  id: "/user/keys",
  path: "/user/keys",
  getParentRoute: () => rootRoute,
} as any);

const ProjectMasterdataRoute = ProjectMasterdataImport.update({
  id: "/project/masterdata",
  path: "/project/masterdata",
  getParentRoute: () => rootRoute,
} as any);

// Populate the FileRoutesByPath interface

declare module "@tanstack/react-router" {
  interface FileRoutesByPath {
    "/": {
      id: "/";
      path: "/";
      fullPath: "/";
      preLoaderRoute: typeof IndexImport;
      parentRoute: typeof rootRoute;
    };
    "/project/masterdata": {
      id: "/project/masterdata";
      path: "/project/masterdata";
      fullPath: "/project/masterdata";
      preLoaderRoute: typeof ProjectMasterdataImport;
      parentRoute: typeof rootRoute;
    };
    "/user/keys": {
      id: "/user/keys";
      path: "/user/keys";
      fullPath: "/user/keys";
      preLoaderRoute: typeof UserKeysImport;
      parentRoute: typeof rootRoute;
    };
    "/project/": {
      id: "/project/";
      path: "/project";
      fullPath: "/project";
      preLoaderRoute: typeof ProjectIndexImport;
      parentRoute: typeof rootRoute;
    };
  }
}

// Create and export the route tree

export interface FileRoutesByFullPath {
  "/": typeof IndexRoute;
  "/project/masterdata": typeof ProjectMasterdataRoute;
  "/user/keys": typeof UserKeysRoute;
  "/project": typeof ProjectIndexRoute;
}

export interface FileRoutesByTo {
  "/": typeof IndexRoute;
  "/project/masterdata": typeof ProjectMasterdataRoute;
  "/user/keys": typeof UserKeysRoute;
  "/project": typeof ProjectIndexRoute;
}

export interface FileRoutesById {
  __root__: typeof rootRoute;
  "/": typeof IndexRoute;
  "/project/masterdata": typeof ProjectMasterdataRoute;
  "/user/keys": typeof UserKeysRoute;
  "/project/": typeof ProjectIndexRoute;
}

export interface FileRouteTypes {
  fileRoutesByFullPath: FileRoutesByFullPath;
  fullPaths: "/" | "/project/masterdata" | "/user/keys" | "/project";
  fileRoutesByTo: FileRoutesByTo;
  to: "/" | "/project/masterdata" | "/user/keys" | "/project";
  id: "__root__" | "/" | "/project/masterdata" | "/user/keys" | "/project/";
  fileRoutesById: FileRoutesById;
}

export interface RootRouteChildren {
  IndexRoute: typeof IndexRoute;
  ProjectMasterdataRoute: typeof ProjectMasterdataRoute;
  UserKeysRoute: typeof UserKeysRoute;
  ProjectIndexRoute: typeof ProjectIndexRoute;
}

const rootRouteChildren: RootRouteChildren = {
  IndexRoute: IndexRoute,
  ProjectMasterdataRoute: ProjectMasterdataRoute,
  UserKeysRoute: UserKeysRoute,
  ProjectIndexRoute: ProjectIndexRoute,
};

export const routeTree = rootRoute
  ._addFileChildren(rootRouteChildren)
  ._addFileTypes<FileRouteTypes>();

/* ROUTE_MANIFEST_START
{
  "routes": {
    "__root__": {
      "filePath": "__root.tsx",
      "children": [
        "/",
        "/project/masterdata",
        "/user/keys",
        "/project/"
      ]
    },
    "/": {
      "filePath": "index.tsx"
    },
    "/project/masterdata": {
      "filePath": "project/masterdata.tsx"
    },
    "/user/keys": {
      "filePath": "user/keys.tsx"
    },
    "/project/": {
      "filePath": "project/index.tsx"
    }
  }
}
ROUTE_MANIFEST_END */
