import{j as e,P as t,a as s,S as i,C as o,b as r,T as n,F as a,f as c,c as l,E as d,W as h}from"./index-Dastpg3d.js";const x="/assets/ert-cKWLsxhL.png",u="/assets/sumo-wazaUMRa.png",j="/assets/webviz-DzFxZuNs.png";function m(){return e.jsxs(i,{children:[e.jsxs(o,{children:[e.jsxs(r.Header,{children:[e.jsx(r.HeaderTitle,{children:e.jsx(n,{variant:"h5",children:"FMU Hub"})}),e.jsx(a,{src:c})]}),e.jsx(r.Content,{children:e.jsx(s,{children:"FMU Hub - the place for everything related to FMU. Expert or noob, user or developer, skeptic or believer - the site is for you and the rest of the amazing FMU community."})}),e.jsx(r.Actions,{children:e.jsx(n,{link:!0,target:"_blank",rel:"noopener noreferrer",href:"https://fmu.equinor.com/",children:"Homepage"})})]}),e.jsxs(o,{children:[e.jsxs(r.Header,{children:[e.jsx(r.HeaderTitle,{children:e.jsx(n,{variant:"h5",children:"Sumo"})}),e.jsx(l,{src:u})]}),e.jsx(r.Content,{children:e.jsx(s,{children:"Sumo is a solution for receiving, storing and serving results produced by numerical predictive models of the subsurface."})}),e.jsxs(r.Actions,{children:[e.jsx(n,{link:!0,target:"_blank",rel:"noopener noreferrer",href:"https://fmu-sumo.app.radix.equinor.com/",children:"Homepage"}),e.jsx(n,{link:!0,target:"_blank",rel:"noopener noreferrer",href:"https://doc-sumo-doc-prod.radix.equinor.com/",children:"Documentation"})]})]}),e.jsxs(o,{children:[e.jsxs(r.Header,{children:[e.jsx(r.HeaderTitle,{children:e.jsx(n,{variant:"h5",children:"ERT"})}),e.jsx(d,{src:x})]}),e.jsx(r.Content,{children:e.jsx(s,{children:"ERT - Ensemble based Reservoir Tool - is a tool to run ensemble-based reservoir models."})}),e.jsx(r.Actions,{children:e.jsx(n,{link:!0,target:"_blank",rel:"noopener noreferrer",href:"https://fmu-docs.equinor.com/docs/ert/index.html",children:"Documentation"})})]}),e.jsxs(o,{children:[e.jsxs(r.Header,{children:[e.jsx(r.HeaderTitle,{children:e.jsx(n,{variant:"h5",children:"Webviz"})}),e.jsx(h,{src:j})]}),e.jsx(r.Content,{children:e.jsx(s,{children:"Webviz is a visualization tool and facilitate easy access of FMU modelling results."})}),e.jsx(r.Actions,{children:e.jsx(n,{link:!0,target:"_blank",rel:"noopener noreferrer",href:"https://webviz.fmu.equinor.com",children:"Documentation"})})]}),e.jsxs(o,{children:[e.jsx(r.Header,{children:e.jsx(r.HeaderTitle,{children:e.jsx(n,{variant:"h5",children:"fmu-dataio"})})}),e.jsx(r.Content,{children:e.jsx(s,{children:"fmu-dataio contains utility functions for data transfer of FMU data with rich metadata, for REP, Sumo, Webviz, etc."})}),e.jsx(r.Actions,{children:e.jsx(n,{link:!0,target:"_blank",rel:"noopener noreferrer",href:"https://fmu-dataio.readthedocs.io/en/latest/",children:"Documentation"})})]})]})}const g=function(){return e.jsxs(e.Fragment,{children:[e.jsx(t,{children:"FMU Settings"}),e.jsx(s,{$variant:"ingress",children:"This is an application for managing the settings of FMU projects."}),e.jsx(m,{})]})};export{g as component};
